@@ -35,6 +35,7 @@
 #include <string.h>
 #include <sys/types.h>
 #include <unistd.h>
+#include <strings.h>
 
 struct mp4_private {
 	char *overflow_buf;
@@ -97,6 +98,7 @@ static int mp4_open(struct input_plugin_data *ip_data)
 	NeAACDecConfigurationPtr neaac_cfg;
 	unsigned char *buf;
 	unsigned int buf_size;
+	int rc = -IP_ERROR_FILE_FORMAT;
 
 
 	/* http://sourceforge.net/forum/message.php?msg_id=3578887 */
@@ -126,6 +128,8 @@ static int mp4_open(struct input_plugin_data *ip_data)
 	priv->mp4.track = mp4_get_track(priv->mp4.handle);
 	if (priv->mp4.track == MP4_INVALID_TRACK_ID) {
 		d_print("MP4FindTrackId failed\n");
+		if (MP4GetNumberOfTracks(priv->mp4.handle, MP4_AUDIO_TRACK_TYPE, 0) > 0)
+			rc = -IP_ERROR_UNSUPPORTED_FILE_TYPE;
 		goto out;
 	}
 
@@ -166,7 +170,7 @@ out:
 	if (priv->decoder)
 		NeAACDecClose(priv->decoder);
 	free(priv);
-	return -IP_ERROR_FILE_FORMAT;
+	return rc;
 }
 
 static int mp4_close(struct input_plugin_data *ip_data)
@@ -325,6 +329,7 @@ static int mp4_read_comments(struct input_plugin_data *ip_data,
 	uint32_t size;*/
 #else
 	const MP4Tags *tags;
+	MP4ItmfItemList* itmf_list;
 #endif
 	GROWING_KEYVALS(c);
 
@@ -361,7 +366,7 @@ static int mp4_read_comments(struct input_plugin_data *ip_data,
 			ustr += 16;
 			size -= 16;
 		}
-		xstr = xmalloc(size + 1);
+		xstr = xnew(char, size + 1);
 		memcpy(xstr, ustr, size);
 		xstr[size] = 0;
 		comments_add(&c, "albumartist", xstr);
@@ -416,6 +421,23 @@ static int mp4_read_comments(struct input_plugin_data *ip_data,
 
 	MP4TagsFree(tags);
 
+	itmf_list = MP4ItmfGetItemsByMeaning(priv->mp4.handle, "com.apple.iTunes", NULL);
+	if (itmf_list) {
+		int i;
+		for (i = 0; i < itmf_list->size; i++) {
+			MP4ItmfItem* item = &itmf_list->elements[i];
+			if (item->dataList.size < 1)
+				continue;
+			if (item->dataList.size > 1)
+				d_print("ignore multiple values for tag %s\n", item->name);
+			else {
+				MP4ItmfData* data = &item->dataList.elements[0];
+				char *val = xstrndup(data->value, data->valueSize);
+				comments_add(&c, item->name, val);
+			}
+		}
+		MP4ItmfItemListFree(itmf_list);
+	}
 #endif
 
 	keyvals_terminate(&c);
@@ -440,14 +462,29 @@ static int mp4_duration(struct input_plugin_data *ip_data)
 	return duration / scale;
 }
 
+static long mp4_bitrate(struct input_plugin_data *ip_data)
+{
+	struct mp4_private *priv = ip_data->private;
+	long bitrate = MP4GetTrackBitRate(priv->mp4.handle, priv->mp4.track);
+	return bitrate ? bitrate : -IP_ERROR_FUNCTION_NOT_SUPPORTED;
+}
+
+static char *mp4_codec(struct input_plugin_data *ip_data)
+{
+	return xstrdup("aac");
+}
+
 const struct input_plugin_ops ip_ops = {
 	.open = mp4_open,
 	.close = mp4_close,
 	.read = mp4_read,
 	.seek = mp4_seek,
 	.read_comments = mp4_read_comments,
-	.duration = mp4_duration
+	.duration = mp4_duration,
+	.bitrate = mp4_bitrate,
+	.codec = mp4_codec
 };
 
+const int ip_priority = 50;
 const char * const ip_extensions[] = { "mp4", "m4a", "m4b", NULL };
 const char * const ip_mime_types[] = { /*"audio/mp4", "audio/mp4a-latm",*/ NULL };
